@@ -2,17 +2,19 @@ use crate::error::Result;
 use crate::events::generate_event_id;
 use crate::events::payload::EventReceivePayload;
 use serde::{Deserialize, Serialize};
+use std::fmt::Debug;
 use tokio::io::{AsyncRead, AsyncReadExt};
 
 /// A container representing an event and underlying binary data.
 /// The data can be decoded into an object representation or read
 /// as raw binary data.
+#[derive(Debug)]
 pub struct Event {
     header: EventHeader,
     data: Vec<u8>,
 }
 
-#[derive(Serialize, Deserialize)]
+#[derive(Debug, Serialize, Deserialize)]
 struct EventHeader {
     id: u64,
     ref_id: Option<u64>,
@@ -22,6 +24,7 @@ struct EventHeader {
 
 impl Event {
     /// Creates a new event with a namespace
+    #[tracing::instrument(level = "trace", skip(data))]
     pub fn with_namespace(
         namespace: String,
         name: String,
@@ -38,6 +41,7 @@ impl Event {
     }
 
     /// Creates a new event
+    #[tracing::instrument(level = "trace", skip(data))]
     pub fn new(name: String, data: Vec<u8>, ref_id: Option<u64>) -> Self {
         let header = EventHeader {
             id: generate_event_id(),
@@ -60,6 +64,7 @@ impl Event {
     }
 
     /// Decodes the data to the given type
+    #[tracing::instrument(level = "trace", skip(self))]
     pub fn data<T: EventReceivePayload>(&self) -> Result<T> {
         let data = T::from_payload_bytes(&self.data[..])?;
 
@@ -82,16 +87,12 @@ impl Event {
     }
 
     /// Reads an event message
+    #[tracing::instrument(level = "trace", skip(reader))]
     pub async fn from_async_read<R: AsyncRead + Unpin>(reader: &mut R) -> Result<Self> {
         let total_length = reader.read_u64().await?;
         let header_length = reader.read_u16().await?;
         let data_length = total_length - header_length as u64;
-        log::trace!(
-            "Parsing event of length {} ({} header, {} data)",
-            total_length,
-            header_length,
-            data_length
-        );
+        tracing::trace!(total_length, header_length, data_length);
 
         let header: EventHeader = {
             let mut header_bytes = vec![0u8; header_length as usize];
@@ -106,11 +107,13 @@ impl Event {
     }
 
     /// Encodes the event into bytes
+    #[tracing::instrument(level = "trace", skip(self))]
     pub fn into_bytes(mut self) -> Result<Vec<u8>> {
         let mut header_bytes = rmp_serde::to_vec(&self.header)?;
         let header_length = header_bytes.len() as u16;
         let data_length = self.data.len();
         let total_length = header_length as u64 + data_length as u64;
+        tracing::trace!(total_length, header_length, data_length);
 
         let mut buf = Vec::with_capacity(total_length as usize);
         buf.append(&mut total_length.to_be_bytes().to_vec());
